@@ -27,11 +27,6 @@ var NAVTREE =
   [ "GNU Radio C++ API Reference", "index.html", [
     [ "Components", "page_components.html", "page_components" ],
     [ "License", "License.html", null ],
-    [ "Release Process Documentation", "page_releasing.html", [
-      [ "Preparation", "page_releasing.html#Preparation", null ],
-      [ "Tagging", "page_releasing.html#Release", null ],
-      [ "Of Archives", "page_releasing.html#Creation", null ]
-    ] ],
     [ "Build Instructions and Information", "build_guide.html", null ],
     [ "Topics", "topics.html", "topics" ],
     [ "Namespaces", "namespaces.html", [
@@ -104,60 +99,61 @@ var NAVTREEINDEX =
 "classgr_1_1digital_1_1symbol__sync__cc.html#afe4b16670fcf5e71c3282cd4762ac142",
 "classgr_1_1dtv_1_1dvbt__bit__inner__interleaver.html",
 "classgr_1_1fec_1_1code_1_1polar__common.html#adcb9476e3f437f427d763814381bee0b",
-"classgr_1_1fec_1_1tpc__decoder.html#a91ed2ddf6aa73eb271d6e8231f7cb815",
-"classgr_1_1filter_1_1freq__xlating__fir__filter.html#a7c54ab3a48e8db3f8717a135be040db0",
+"classgr_1_1fec_1_1tpc__decoder.html#ac71a3fe1b3074d0392bbf0ae025cd713",
+"classgr_1_1filter_1_1freq__xlating__fir__filter.html#a7f6703c0ad752e773fff3aa90a867656",
 "classgr_1_1filter_1_1kernel_1_1pfb__arb__resampler__ccc.html#a06bb98d48c99e45b3f36dd95bdbd1f83",
-"classgr_1_1filter_1_1single__pole__iir.html#aa8d14823d7649449309387443c133615",
-"classgr_1_1iio_1_1device__sink.html#a04d0a5ca52ecd9cab96ffa858717cf05",
-"classgr_1_1msg__accepter.html#a1032a8f3bf410b7670bc9af0c7c6d7ad",
-"classgr_1_1qtgui_1_1ber__sink__b.html#a6a670553381933476126c820caa03a20",
-"classgr_1_1qtgui_1_1eye__sink__f.html#ad0a17ef061f38d8e0adee502343d0a08",
-"classgr_1_1qtgui_1_1histogram__sink__f.html#ad73087a5d4587d1f0f1524e3df7e406f",
-"classgr_1_1qtgui_1_1time__raster__sink__f.html#a6d9764d819fa106484ed54b40282960d",
-"classgr_1_1qtgui_1_1vector__sink__f.html#a7cca97a9247ddbe46fab0a0cfea4c190",
-"classgr_1_1soapy_1_1block.html#a2fa3ac00cebd970648557800316bcd1a",
-"classgr_1_1trellis_1_1fsm.html",
-"classgr_1_1uhd_1_1rfnoc__duc.html#a17bdf06529d229806eefed70149180cc",
-"classgr_1_1vocoder_1_1alaw__decode__bs.html#aec1a4c451c9057ea31a318ae531c8a8c",
-"classpmt_1_1pmt__base.html#a4dff1d4b51e49eb4474b3bb938b8e9b9",
-"classrpcextractor__base.html#afb9a96dc63c5144792ca5e086476818f",
-"complex__to__mag__squared__pydoc__template_8h_source.html",
-"conv__bit__corr__bb__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
-"ctcss__squelch__ff__pydoc__template_8h.html#a6dc864432aa28f5358748b9a75fd9361",
-"dictionary__logger__backend__pydoc__template_8h_source.html",
-"dir_d0df2b74cf468c679c2d810febf4db4f.html",
-"dvbt2__p1insertion__cc__pydoc__template_8h.html#ac6338bfa6c3600933d96dbab1358198f",
-"eye__sink__c__pydoc__template_8h.html#a81990ccc681daa2081282e41990430e6",
-"file__sink__base__pydoc__template_8h.html#a89efc4cc990972e0ab92b34c277b9821",
-"fmcomms2__sink__f32c__pydoc__template_8h.html#a2a1b37c5a97a55c6449e7b8f935094c4",
-"functions_func_g.html",
-"glfsr__source__b__pydoc__template_8h.html",
-"group__coding__blk.html",
-"hilbert__fc__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
-"keep__one__in__n__pydoc__template_8h_source.html",
-"maxstar_8h.html#a2c320230820ada5cf49c1932925ac6fc",
-"msg__accepter__pydoc__template_8h.html",
-"namespacegr_1_1blocks.html#a2da706db5e765a2753bcfe47af7e2112",
-"namespacegr_1_1dtv.html#a35dea4c78a05851f4beae107d010e26aa309ee473cb6a05ac8341f83798f2fd12",
-"namespacegr_1_1paths.html#a0a63932f3295c2519ab6d96dd94a6871",
-"namespacemembers_g.html",
-"namespacepmt.html#ad036139df4d306b1547307bd22ce6208",
-"osx__impl_8h.html",
-"pdu__pydoc__template_8h.html#a66835b07b591aef5524786a0faf59706",
-"pfb__clock__sync__ccf__pydoc__template_8h_source.html",
-"pmt__pydoc__template_8h.html#a2e972576b7af59553507af5d1ecd32be",
-"pmt__serial__tags_8h.html#abdf3c401a44b88c89208285f00d6643fab9dd89f1ce8ffa07c84543ca7ac758db",
-"protocol__formatter__async_8h.html",
-"rep__msg__sink__pydoc__template_8h.html#a2315145bc34c097d964acfa640229538",
-"rfnoc__tx__radio__pydoc__template_8h.html#af17c3b4b4f030cab9bd18503f077a9f2",
-"short__to__float__pydoc__template_8h_source.html",
-"sro__model__pydoc__template_8h.html#a159be69a980c7393012cf69d67e11904",
-"structrpcbasic__register__trigger.html#a895792c3924627295fca7ea1dbbd0e82",
-"tagged__file__sink_8h.html",
-"time__sink__c_8h_source.html",
-"ulaw__decode__bs__pydoc__template_8h.html#adef71bf24863902abf7b387c03f3a23c",
-"vector__sink__f__pydoc__template_8h.html#adff873daa7fcd985ca0061a4611f32bb"
+"classgr_1_1filter_1_1single__pole__iir_3_01gr__complex_00_01i__type_00_01double_01_4.html#a16a18c30612337692adc76769323d18e",
+"classgr_1_1iio_1_1device__source.html#adbbbd5fee5d4b2b2d00d0637301b88b7",
+"classgr_1_1msg__endpoint.html#a14bc4ad779b24c77c975b0f6c1b6649b",
+"classgr_1_1qtgui_1_1ber__sink__b.html#abbc064f162da722fe8663090fc7b9987",
+"classgr_1_1qtgui_1_1freq__sink__c.html#a0187a0131152e4d60e71659079c44f51",
+"classgr_1_1qtgui_1_1histogram__sink__f.html#afc05c848d11e435817f4100575362359",
+"classgr_1_1qtgui_1_1time__raster__sink__f.html#aa6baf71669fba0c9cbe310d789ea101f",
+"classgr_1_1qtgui_1_1vector__sink__f.html#abf103c04cd69da087714cb88c099d971",
+"classgr_1_1soapy_1_1block.html#a4cfc22e114a2006a293577a82d3c3dbc",
+"classgr_1_1trellis_1_1fsm.html#ae8cdb8948e2f148f18c7612d419b996d",
+"classgr_1_1uhd_1_1rfnoc__graph.html#a55f922bbeae810da681b5db9c72624d0",
+"classgr_1_1vocoder_1_1codec2.html#a4fb8331472faad41468ffdd68654e6f1aa299e9caf16a658972dccf581e3979a3",
+"classpmt_1_1pmt__base.html#a97bac3d60aa2f86fece6565f34fc4648",
+"classrpcserver__base.html#ad65d23a4b1e9bfec36bdb3a17df14d22",
+"const__sink__c__pydoc__template_8h.html#afef2276891fa94711966c62d85ec4ef9",
+"correctiq__man__pydoc__template_8h.html#ae8e255dc25d8f1410ec44cb3e2fbd8c2",
+"ctrlport__probe2__s__pydoc__template_8h.html#ac67ab9a2308b2c8abd2ea0df550b2e9d",
+"dir_1addaf4707bd91d3a75e5938322db1c2.html",
+"divide__pydoc__template_8h_source.html",
+"dvbt__demap__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
+"eye__sink__f__pydoc__template_8h.html#adc224d76e91d59a31e32eeaca7a4d49d",
+"fir__filter__blk__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
+"freedv__rx__ss__pydoc__template_8h.html",
+"functions_vars_o.html",
+"globals_u.html",
+"gsm__fr__decode__ps__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
+"iio__types_8h_source.html",
+"ldpc__encoder__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
+"message__pydoc__template_8h.html#ab34236d1a5defbf80ff495b96505860f",
+"multiply__by__tag__value__cc__pydoc__template_8h.html#aec4e99f2e3c60c1e67b14679a24a9e13",
+"namespacegr_1_1blocks.html#a950deab7c13b90f6dc4a2e988bbff194",
+"namespacegr_1_1dtv.html#a6a7633d61ed04d9f2d4629c46553300a",
+"namespacegr_1_1soapy.html#a686b7b56e6d57f8973771981f974e37d",
+"namespacepmt.html#a0f83b416a4813215c1c5820511797408",
+"nlog10__ff__pydoc__template_8h.html#a107e3570a940a14fc691ae1fb43f24ca",
+"packet__headergenerator__bb__pydoc__template_8h.html#aa3ea89a9935e22592562763eccb5a287",
+"peak__detector2__fb__pydoc__template_8h.html#ab8b318b9da474c27b221db6d6c4bf926",
+"pfb__synthesizer__ccf__pydoc__template_8h_source.html",
+"pmt__pydoc__template_8h.html#a6e72b8bf726253c1f98525a89ada72fc",
+"polar__decoder__sc_8h_source.html",
+"puncture__bb_8h.html",
+"req__msg__source__pydoc__template_8h.html#a7bbd30c8440813ea95cd746c3a0811bd",
+"rpccallbackregister__base_8h.html",
+"sink__c__pydoc__template_8h.html#a0eb827f060bd9875dd5cbff632f6cdb6",
+"streams__to__vector__pydoc__template_8h.html",
+"structrpcpmtconverter_1_1to__pmt__short__f.html",
+"tags__strobe__pydoc__template_8h.html#a4bfec3c39cb83a44e01a13d401dc4544",
+"time__sink__f__pydoc__template_8h.html#a8955a83687cf8114772f692df46ba3ec",
+"usrp__block__pydoc__template_8h.html#a54333908d48c9b32dd4d9da4cf1d9c32",
+"waterfall__sink__c__pydoc__template_8h.html#a7c65bc82725601e2a49c69d42b3b673d"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronization';
-var SYNCOFFMSG = 'click to enable panel synchronization';
\ No newline at end of file
+var SYNCOFFMSG = 'click to enable panel synchronization';
+var LISTOFALLMEMBERS = 'List of all members';
\ No newline at end of file
